import jcmwave
import numpy as np
import os

instance_info = dict(
    Hostname = '<EC2 DNS>',
    Login = 'ec2-user',
    PEMFile = '<PATH TO PEM FILE>',
    JCMROOT = '/home/ec2-user/bin/JCMsuite')

jcmwave.daemon.install_remote_environment(
                      IncludePython = False,
                      **instance_info)

jcmwave.daemon.add_workstation(
                      NThreads = 1,
                      LicenseServerPort = 8992,
                      **instance_info)

# run some parallel parameter scan (see Tutorial example 'Parallel Parameter Scan')
radii = np.linspace(0.3, 0.5, 4)
job_ids = []

for radius in radii:
    keys = {'radius': radius}
    job_id = jcmwave.solve('mie2D.jcmp', keys=keys, 
        logfile = open(os.devnull, 'w'), 
        temporary = True
        )
    job_ids.append(job_id)

results, logs = jcmwave.daemon.wait(job_ids = job_ids)    
scattering_cross_section_scan = []
for iR in range(len(radii)):
    scs = results[iR][1]['ElectromagneticFieldEnergyFlux'][0][0].real
    scattering_cross_section_scan.append(scs)

# plot scattering cross section against rod radius
from matplotlib.pyplot import *
plot(radii, scattering_cross_section_scan, '-+', linewidth=2, markersize=14)
xlabel('radius [$\mu$ m]', fontsize=14)
ylabel('integral scattering cross section', fontsize=14)
axis('tight')
show()
jcmwave.daemon.shutdown()
