import jcmwave
import numpy as np
import os

jcmwave.daemon.shutdown()
jcmwave.daemon.add_workstation(Hostname ='localhost', 
                               Multiplicity = 2, 
                               NThreads = 1)

radii = np.linspace(0.3, 0.5, 40)
job_ids = []

# loop over radius values
for radius in radii:

    keys = {'radius': radius}
    # jcmwave_solve immediately returns  a job identifier
    job_id = jcmwave.solve('mie2D.jcmp', keys=keys, 
        temporary = True
        )
    job_ids.append(job_id)

# here we wait until all jobs are finished
results, logs = jcmwave.daemon.wait(job_ids = job_ids)    

# now we collect the computed scattering cross section 
# as in the the sequential example 
scattering_cross_section_scan = []
for iR in range(len(radii)):
    scs = results[iR][1]['ElectromagneticFieldEnergyFlux'][0][0].real
    scattering_cross_section_scan.append(scs)

# plot scattering cross section against rod radius
from matplotlib.pyplot import *
plot(radii, scattering_cross_section_scan, '-+', linewidth=2, markersize=14)
xlabel('radius [$\mu$ m]', fontsize=14)
ylabel('integral scattering cross section', fontsize=14)
axis('tight')
show()
