import jcmwave
import numpy as np
import os

# holds computed scattering cross sections
scattering_cross_section_scan = []

# loop over radius values
radii = np.linspace(0.3, 0.5, 40)
for radius in  radii:
    print ('Solving for radius %5.2e' %(radius,))
    
    # set current parameter and solve the project
    keys = {'radius': radius}
    results = jcmwave.solve('mie2D.jcmp', keys=keys, 
        logfile=open(os.devnull, 'w'))
    
    scs = results[1]['ElectromagneticFieldEnergyFlux'][0][0].real
    
    # gather results
    scattering_cross_section_scan.append(scs)


# plot scattering cross section against rod radius
from matplotlib.pyplot import *
plot(radii, scattering_cross_section_scan, '-+', linewidth=2, markersize=14)
xlabel('radius [$\mu$ m]', fontsize=14)
ylabel('integral scattering cross section', fontsize=14)
axis('tight')
show()


